// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KIDENTITYMANAGEMENTWIDGETS_VERSION_H
#define KIDENTITYMANAGEMENTWIDGETS_VERSION_H

#define KIDENTITYMANAGEMENTWIDGETS_VERSION_STRING "6.7.0"
#define KIDENTITYMANAGEMENTWIDGETS_VERSION_MAJOR 6
#define KIDENTITYMANAGEMENTWIDGETS_VERSION_MINOR 7
#define KIDENTITYMANAGEMENTWIDGETS_VERSION_PATCH 0
#define KIDENTITYMANAGEMENTWIDGETS_VERSION ((6<<16)|(7<<8)|(0))

#endif
