
#ifndef KIDENTITYMANAGEMENTQUICK_EXPORT_H
#define KIDENTITYMANAGEMENTQUICK_EXPORT_H

#ifdef KIDENTITYMANAGEMENTQUICK_STATIC_DEFINE
#  define KIDENTITYMANAGEMENTQUICK_EXPORT
#  define KIDENTITYMANAGEMENTQUICK_NO_EXPORT
#else
#  ifndef KIDENTITYMANAGEMENTQUICK_EXPORT
#    ifdef KPim6IdentityManagementQuick_EXPORTS
        /* We are building this library */
#      define KIDENTITYMANAGEMENTQUICK_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KIDENTITYMANAGEMENTQUICK_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KIDENTITYMANAGEMENTQUICK_NO_EXPORT
#    define KIDENTITYMANAGEMENTQUICK_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KIDENTITYMANAGEMENTQUICK_DEPRECATED
#  define KIDENTITYMANAGEMENTQUICK_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KIDENTITYMANAGEMENTQUICK_DEPRECATED_EXPORT
#  define KIDENTITYMANAGEMENTQUICK_DEPRECATED_EXPORT KIDENTITYMANAGEMENTQUICK_EXPORT KIDENTITYMANAGEMENTQUICK_DEPRECATED
#endif

#ifndef KIDENTITYMANAGEMENTQUICK_DEPRECATED_NO_EXPORT
#  define KIDENTITYMANAGEMENTQUICK_DEPRECATED_NO_EXPORT KIDENTITYMANAGEMENTQUICK_NO_EXPORT KIDENTITYMANAGEMENTQUICK_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KIDENTITYMANAGEMENTQUICK_NO_DEPRECATED
#    define KIDENTITYMANAGEMENTQUICK_NO_DEPRECATED
#  endif
#endif

#endif /* KIDENTITYMANAGEMENTQUICK_EXPORT_H */
