
#ifndef KIDENTITYMANAGEMENTCORE_EXPORT_H
#define KIDENTITYMANAGEMENTCORE_EXPORT_H

#ifdef KIDENTITYMANAGEMENTCORE_STATIC_DEFINE
#  define KIDENTITYMANAGEMENTCORE_EXPORT
#  define KIDENTITYMANAGEMENTCORE_NO_EXPORT
#else
#  ifndef KIDENTITYMANAGEMENTCORE_EXPORT
#    ifdef KPim6IdentityManagementCore_EXPORTS
        /* We are building this library */
#      define KIDENTITYMANAGEMENTCORE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KIDENTITYMANAGEMENTCORE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KIDENTITYMANAGEMENTCORE_NO_EXPORT
#    define KIDENTITYMANAGEMENTCORE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KIDENTITYMANAGEMENTCORE_DEPRECATED
#  define KIDENTITYMANAGEMENTCORE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KIDENTITYMANAGEMENTCORE_DEPRECATED_EXPORT
#  define KIDENTITYMANAGEMENTCORE_DEPRECATED_EXPORT KIDENTITYMANAGEMENTCORE_EXPORT KIDENTITYMANAGEMENTCORE_DEPRECATED
#endif

#ifndef KIDENTITYMANAGEMENTCORE_DEPRECATED_NO_EXPORT
#  define KIDENTITYMANAGEMENTCORE_DEPRECATED_NO_EXPORT KIDENTITYMANAGEMENTCORE_NO_EXPORT KIDENTITYMANAGEMENTCORE_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KIDENTITYMANAGEMENTCORE_NO_DEPRECATED
#    define KIDENTITYMANAGEMENTCORE_NO_DEPRECATED
#  endif
#endif

#endif /* KIDENTITYMANAGEMENTCORE_EXPORT_H */
